@@ -1,4 +1,4 @@
-import os, sys, pygame
+import os, sys, inspect, pygame
 from .originator import *
 from .careTaker import *
 from .orientation import *
@@ -7,7 +7,7 @@ from .orientation import *
 cmd_subfolder_grid = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"grid")))
 if cmd_subfolder_grid not in sys.path:
     sys.path.insert(0, cmd_subfolder_grid)
-    
+
 from .test import *
 
 from random import randint
